pub enum TxnFailureCause {
NoneByCommitted,
NoneByUncommitted,
LogicFailure(Err),
CommitFailure(Err),
PostCommitFailure(Err),
}Expand description
Represents the cause of a transaction failure for a specific data connection.
Variants
NoneByCommitted
No failure occurred, and the transaction was successfully committed.
NoneByUncommitted
No failure occurred, but the transaction was not committed (e.g., because another connection in the transaction failed before this one could commit).
LogicFailure(Err)
The logic execution or pre-commit phase of the data connection failed.
CommitFailure(Err)
The commit phase of the data connection failed.
PostCommitFailure(Err)
The post-commit phase of the data connection failed.