pub struct TxnFailureReport {
pub data_conn_name: Arc<str>,
pub data_conn_type: &'static str,
pub cause: TxnFailureCause,
pub rollback: TxnFailureRollback,
}Expand description
A report detailing the transaction failure cause and rollback status for a specific data connection.
Fields
data_conn_name: Arc<str>The name of the data connection.
data_conn_type: &'static strThe type name of the data connection.
cause: TxnFailureCauseThe cause of the transaction failure.
rollback: TxnFailureRollbackThe rollback status of the data connection.
Implementations
Sourceimpl TxnFailureReport
impl TxnFailureReport
Sourcepub fn is_cause_of_failure(&self) -> bool
pub fn is_cause_of_failure(&self) -> bool
Returns true if this connection was a cause of the transaction failure.
Sourcepub fn recovery_for_commit(&self) -> TxnFailureRecovery
pub fn recovery_for_commit(&self) -> TxnFailureRecovery
Determines the suggested recovery action for this connection to achieve a successful commit.
Sourcepub fn recovery_for_rollback(&self) -> TxnFailureRecovery
pub fn recovery_for_rollback(&self) -> TxnFailureRecovery
Determines the suggested recovery action to achieve a rolled-back state for this connection.