AutoShutdown

Struct AutoShutdown 

pub struct AutoShutdown {}
Available on crate feature tokio only.
A marker struct that can be used to trigger automatic shutdown behavior for resources managed by the DataHub when it goes out of scope.