pub enum TxnFailureRecovery {
NoActionRequired,
RerunLogicAndCommit,
ResolveCauseThenRerunLogicAndCommit,
ResolveCauseThenRerunPostCommit,
ResolveCauseAndInconsistency,
InvestigateBecauseImpossible,
ManualRollbackRequired,
}Expand description
Represents the suggested recovery action for a data connection after a transaction failure.
Variants
NoActionRequired
No recovery action is required.
RerunLogicAndCommit
The transaction was successfully rolled back. The transaction can be rerun a logic and committed again.
ResolveCauseThenRerunLogicAndCommit
The transaction failed to run a logic or pre commit. After resolving the cause, the transaction can be rerun a logic and commit again.
ResolveCauseThenRerunPostCommit
The transaction failed to run post commit. After resolving the cause, the transaction can be rerun post commit again.
ResolveCauseAndInconsistency
The rollback failed and it may be in an inconsistent state. Resolve the cause and inconsistent state.
InvestigateBecauseImpossible
It is in impossile case under normal conditions. Investigation of the cause is required.
ManualRollbackRequired
The transaction was successfully committed. It is required to rollback manually.