TxnFailureReport

Struct TxnFailureReport 

pub struct TxnFailureReport {
    pub data_conn_name: Arc<str>,
    pub data_conn_type: &'static str,
    pub cause: TxnFailureCause,
    pub rollback: TxnFailureRollback,
}
A report detailing the transaction failure cause and rollback status for a specific data connection.

Fields

data_conn_name: Arc<str>

The name of the data connection.

data_conn_type: &'static str

The type name of the data connection.

cause: TxnFailureCause

The cause of the transaction failure.

rollback: TxnFailureRollback

The rollback status of the data connection.

Implementations

Source

impl TxnFailureReport

pub fn is_cause_of_failure(&self) -> bool

Returns true if this connection was a cause of the transaction failure.

pub fn recovery_for_commit(&self) -> TxnFailureRecovery

Determines the suggested recovery action for this connection to achieve a successful commit.

pub fn recovery_for_rollback(&self) -> TxnFailureRecovery

Determines the suggested recovery action to achieve a rolled-back state for this connection.