pub enum DataHubError {
FailToSetupLocalDataSrcs {
errors: Vec<(Arc<str>, Err)>,
},
NoDataSrcToCreateDataConn {
name: Arc<str>,
data_conn_type: &'static str,
},
}Available on crate feature
tokio only.Expand description
Represents errors that can occur within the DataHub.
Variants
FailToSetupLocalDataSrcs
An error indicating that one or more local data sources failed during their setup processes.
Fields
NoDataSrcToCreateDataConn
An error indicating that no suitable data source was found to create a data connection with the specified name and type.