pub struct AsyncGroup { /* private fields */ }Available on crate feature
tokio only.Expand description
Manages a collection of asynchronous tasks, allowing them to be executed concurrently and their results (or errors) collected.
Implementations
Sourceimpl AsyncGroup
impl AsyncGroup
Sourcepub fn add<Fut>(&mut self, future: Fut)
pub fn add<Fut>(&mut self, future: Fut)
Adds a future to the AsyncGroup to be executed concurrently.
The provided future will be polled along with others in this group.
Arguments
future- The future to add. It must implementFuture<Output = errs::Result<()>>,Send, and have a'staticlifetime.